===============
Version History
===============

.. automodule:: tafra
   :noindex:


1.0.1
-----

* Add iter functions
* Add map functions
* Various constructor improvements


1.0.0
-----

* Initial Release
